Index: c/src/lib/libbsp/m68k/gen68302/ChangeLog
===================================================================
--- c/src/lib/libbsp/m68k/gen68302/ChangeLog	(revision 722ab6dd0396d11c216bfefd26d0fc908951b09f)
+++ c/src/lib/libbsp/m68k/gen68302/ChangeLog	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
@@ -1,2 +1,7 @@
+2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
+
+	* timer/timer.c, timer/timerisr.S: Eliminate empty function from every
+	benchmark timer driver. Fix spelling.
+
 2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
 
Index: c/src/lib/libbsp/m68k/gen68302/timer/timerisr.S
===================================================================
--- c/src/lib/libbsp/m68k/gen68302/timer/timerisr.S	(revision 722ab6dd0396d11c216bfefd26d0fc908951b09f)
+++ c/src/lib/libbsp/m68k/gen68302/timer/timerisr.S	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
@@ -5,5 +5,5 @@
  * accuracy of RTEMS' timing test suite.
  *
- * See also:	benchmark_timerread()
+ * See also:	benchmark_timer_read()
  *
  * To reduce overhead this is best to be the "rawest" hardware interupt
Index: c/src/lib/libbsp/m68k/mvme167/ChangeLog
===================================================================
--- c/src/lib/libbsp/m68k/mvme167/ChangeLog	(revision 722ab6dd0396d11c216bfefd26d0fc908951b09f)
+++ c/src/lib/libbsp/m68k/mvme167/ChangeLog	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
@@ -1,2 +1,7 @@
+2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
+
+	* timer/timer.c, timer/timerisr.S: Eliminate empty function from every
+	benchmark timer driver. Fix spelling.
+
 2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
 
Index: c/src/lib/libbsp/m68k/mvme167/timer/timerisr.S
===================================================================
--- c/src/lib/libbsp/m68k/mvme167/timer/timerisr.S	(revision 722ab6dd0396d11c216bfefd26d0fc908951b09f)
+++ c/src/lib/libbsp/m68k/mvme167/timer/timerisr.S	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
@@ -3,5 +3,5 @@
  *  This ISR is used to bump a count of interval "overflow" interrupts which
  *  have occurred since the timer was started. The number of overflows is taken
- *  into account in the benchmark_timerread() routine.
+ *  into account in the benchmark_timer_read() routine.
  *
  *  Input parameters:  NONE
Index: c/src/lib/libbsp/m68k/ods68302/ChangeLog
===================================================================
--- c/src/lib/libbsp/m68k/ods68302/ChangeLog	(revision 722ab6dd0396d11c216bfefd26d0fc908951b09f)
+++ c/src/lib/libbsp/m68k/ods68302/ChangeLog	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
@@ -1,2 +1,7 @@
+2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
+
+	* timer/timer.c, timer/timerisr.S: Eliminate empty function from every
+	benchmark timer driver. Fix spelling.
+
 2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
 
Index: c/src/lib/libbsp/m68k/ods68302/timer/timerisr.S
===================================================================
--- c/src/lib/libbsp/m68k/ods68302/timer/timerisr.S	(revision 722ab6dd0396d11c216bfefd26d0fc908951b09f)
+++ c/src/lib/libbsp/m68k/ods68302/timer/timerisr.S	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
@@ -5,5 +5,5 @@
  * accuracy of RTEMS' timing test suite.
  *
- * See also:	benchmark_timerread()
+ * See also:	benchmark_timer_read()
  *
  * To reduce overhead this is best to be the "rawest" hardware interupt

Index: c/src/lib/libbsp/m68k/gen68302/timer/timer.c
===================================================================
--- c/src/lib/libbsp/m68k/gen68302/timer/timer.c	(revision 722ab6dd0396d11c216bfefd26d0fc908951b09f)
+++ c/src/lib/libbsp/m68k/gen68302/timer/timer.c	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
@@ -41,9 +41,9 @@
 uint32_t         Timer_interrupts;
 
-rtems_boolean benchmark_timerfind_average_overhead;
+rtems_boolean benchmark_timer_find_average_overhead;
 
 rtems_isr timerisr(void);
 
-void benchmark_timerinitialize( void )
+void benchmark_timer_initialize( void )
 {
     m302.reg.tmr2 = 0;			/* disable timer */
@@ -57,5 +57,5 @@
 
 /*
  *  The following controls the behavior of benchmark_timerread().
  *
  *  FIND_AVG_OVERHEAD *  instructs the routine to return the "raw" count.
@@ -76,5 +76,5 @@
  * Return timer value in 1/2-microsecond units
  */
-int benchmark_timerread( void )
+int benchmark_timer_read( void )
 {
   uint16_t         clicks;
@@ -96,5 +96,5 @@
   total = (Timer_interrupts * TRR2_VAL) + clicks;
 
-  if ( benchmark_timerfind_average_overhead == 1 )
+  if ( benchmark_timer_find_average_overhead == 1 )
     return total;          /* in XXX microsecond units */
 
@@ -109,18 +109,8 @@
 }
 
-/*
- *  Empty function call used in loops to measure basic cost of looping
- *  in Timing Test Suite.
- */
-
-rtems_status_code benchmark_timerempty_function(void)
-{
-    return RTEMS_SUCCESSFUL;
-}
-
-void benchmark_timerdisable_subtracting_average_overhead(
+void benchmark_timer_disable_subtracting_average_overhead(
   rtems_boolean find_flag
 )
 {
-  benchmark_timerfind_average_overhead = find_flag;
+  benchmark_timer_find_average_overhead = find_flag;
 }
@@ -57,5 +57,5 @@
 
 /*
- *  The following controls the behavior of benchmark_timerread().
+ *  The following controls the behavior of benchmark_timer_read().
  *
  *  FIND_AVG_OVERHEAD *  instructs the routine to return the "raw" count.
Index: c/src/lib/libbsp/m68k/mvme167/timer/timer.c
===================================================================
--- c/src/lib/libbsp/m68k/mvme167/timer/timer.c	(revision 722ab6dd0396d11c216bfefd26d0fc908951b09f)
+++ c/src/lib/libbsp/m68k/mvme167/timer/timer.c	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
@@ -2,7 +2,7 @@
  *
  *  This file manages the benchmark timer used by the RTEMS Timing Test Suite.
  *  Each measured time period is demarcated by calls to benchmark_timerinitialize() and
  *  benchmark_timerread().  benchmark_timerread() usually returns the number of microseconds
  *  since benchmark_timerinitialize() exitted.
  *
  *  These functions are prototyped in rtems/c/src/lib/include/timerdrv.h and
@@ -47,5 +47,5 @@
  *  time.
  */
-rtems_boolean       benchmark_timerfind_average_overhead;
+rtems_boolean       benchmark_timer_find_average_overhead;
 
 rtems_isr timerisr(void);
@@ -71,5 +71,5 @@
  *  prescaler value should be 0xE7 (page 2-63).
  */
-void benchmark_timerinitialize(void)
+void benchmark_timer_initialize(void)
 {
   (void) set_vector( timerisr, TIMER_VECTOR, 0 );
@@ -106,5 +106,5 @@
  *  below this are "noise" and zero is returned.
  */
-int benchmark_timerread(void)
+int benchmark_timer_read(void)
 {
   uint32_t            total;
@@ -112,5 +112,5 @@
   total = (Ttimer_val * TICK_INTERVAL) + lcsr->timer_cnt_1;
 
-  if ( benchmark_timerfind_average_overhead )
+  if ( benchmark_timer_find_average_overhead )
     return total;          /* in one microsecond units */
 
@@ -122,18 +122,5 @@
 
 /*
- *  Empty function call used in loops to measure basic cost of looping
- *  in Timing Test Suite.
- *
- *  Input parameters:  NONE
- *
- *  Output parameters:  time in microseconds
- */
-rtems_status_code benchmark_timerempty_function( void )
-{
-  return RTEMS_SUCCESSFUL;
-}
-
-/*
- *  This routine sets the benchmark_timerfind_average_overhead flag in this
+ *  This routine sets the benchmark_timer_find_average_overhead flag in this
  *  module.
  *
@@ -142,8 +129,8 @@
  *  Output parameters:  time in microseconds
  */
-void benchmark_timerdisable_subtracting_average_overhead(
+void benchmark_timer_disable_subtracting_average_overhead(
   rtems_boolean find_flag
 )
 {
-  benchmark_timerfind_average_overhead = find_flag;
+  benchmark_timer_find_average_overhead = find_flag;
 }
@@ -2,7 +2,7 @@
  *
  *  This file manages the benchmark timer used by the RTEMS Timing Test Suite.
- *  Each measured time period is demarcated by calls to benchmark_timerinitialize() and
- *  benchmark_timerread().  benchmark_timerread() usually returns the number of microseconds
- *  since benchmark_timerinitialize() exitted.
+ *  Each measured time period is demarcated by calls to benchmark_timer_initialize() and
+ *  benchmark_timer_read().  benchmark_timer_read() usually returns the number of microseconds
+ *  since benchmark_timer_initialize() exitted.
  *
  *  These functions are prototyped in rtems/c/src/lib/include/timerdrv.h and
Index: c/src/lib/libbsp/m68k/ods68302/timer/timer.c
===================================================================
--- c/src/lib/libbsp/m68k/ods68302/timer/timer.c	(revision 722ab6dd0396d11c216bfefd26d0fc908951b09f)
+++ c/src/lib/libbsp/m68k/ods68302/timer/timer.c	(revision 6b2923cbc3d60fb3c204677bb0eed2afaedfa0c7)
@@ -41,9 +41,9 @@
 uint32_t         Timer_interrupts;
 
-rtems_boolean benchmark_timerfind_average_overhead;
+rtems_boolean benchmark_timer_find_average_overhead;
 
 rtems_isr timerisr(void);
 
-void benchmark_timerinitialize( void )
+void benchmark_timer_initialize( void )
 {
     m302.reg.tmr2 = 0;			/* disable timer */
@@ -57,5 +57,5 @@
 
 /*
  *  The following controls the behavior of benchmark_timerread().
  *
  *  FIND_AVG_OVERHEAD *  instructs the routine to return the "raw" count.
@@ -76,5 +76,5 @@
  * Return timer value in 1/2-microsecond units
  */
-int benchmark_timerread( void )
+int benchmark_timer_read( void )
 {
   uint16_t         clicks;
@@ -96,5 +96,5 @@
   total = (Timer_interrupts * TRR2_VAL) + clicks;
 
-  if ( benchmark_timerfind_average_overhead == 1 )
+  if ( benchmark_timer_find_average_overhead == 1 )
     return total;          /* in XXX microsecond units */
 
@@ -109,18 +109,8 @@
 }
 
-/*
- *  Empty function call used in loops to measure basic cost of looping
- *  in Timing Test Suite.
- */
-
-rtems_status_code benchmark_timerempty_function(void)
-{
-    return RTEMS_SUCCESSFUL;
-}
-
-void benchmark_timerdisable_subtracting_average_overhead(
+void benchmark_timer_disable_subtracting_average_overhead(
   rtems_boolean find_flag
 )
 {
-  benchmark_timerfind_average_overhead = find_flag;
+  benchmark_timer_find_average_overhead = find_flag;
 }
@@ -57,5 +57,5 @@
 
 /*
- *  The following controls the behavior of benchmark_timerread().
+ *  The following controls the behavior of benchmark_timer_read().
  *
  *  FIND_AVG_OVERHEAD *  instructs the routine to return the "raw" count.